%define major		5
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

Summary:	Free and open source C++ spell checking library 
Name:		nuspell
Version:	5.1.5
Release:	%mkrel 1
License:	LGPLv3+
Group:		System/Internationalization
Url:		https://nuspell.github.io/
Source0:	https://github.com/nuspell/nuspell/archive/v%{version}/%{name}-%{version}.tar.gz
# Add DLL version suffix
Patch0:		nuspell-dllver.patch

BuildRequires:	cmake
BuildRequires:	boost-devel
BuildRequires:	pkgconfig(icu-uc)
BuildRequires:	pkgconfig(catch2)

### mingw
BuildRequires:	mingw32-filesystem
BuildRequires:	mingw32-dlfcn
BuildRequires:	mingw32-gcc-c++
BuildRequires:	mingw32-icu

BuildRequires:	mingw64-filesystem
BuildRequires:	mingw64-dlfcn
BuildRequires:	mingw64-gcc-c++
BuildRequires:	mingw64-icu

Recommends:	myspell-en

%description
Nuspell is a free and open source spell checker library and command-line program
designed for languages with rich morphology and complex word compounding.
Nuspell is a pure C++ re-implementation of Hunspell.
Main features of Nuspell spell checker:

* Full unicode support backed by ICU
* Backward compatibility with Hunspell dictionary file format
* Twofold affix stripping (for agglutinative languages, like Azeri, Basque,
    Estonian, Finnish, Hungarian, Turkish, etc.)
* Support complex compounds (for example, Hungarian, German and Dutch)
* Support language specific features (for example, special casing of Azeri and
    Turkish dotted i, or German sharp s)
* Handle conditional affixes, circumfixes, fogemorphemes, forbidden words,
    pseudoroots and homonyms.
* Free software. Licensed under GNU LGPL v3 or later.

%package -n %{libname}
Summary:	Main library for %{name}
Group:		System/Libraries
Recommends:	myspell-en

%description -n %{libname}
Main library for %{name}.

%package -n %{develname}
Summary:	Development and header files for %{name}
Group:		Development/C++
Requires:	%{libname} >= %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{develname}
Development files and headers for %{name}.

### mingw
%package -n mingw32-%{name}
Summary:	MinGW Windows %{name} library
Group:		Development/Other
BuildArch:	noarch

%description -n mingw32-%{name}
MinGW Windows %{pkgname} library.

%package -n mingw64-%{name}
Summary:	MinGW Windows %{name} library
Group:		Development/Other
BuildArch:	noarch

%description -n mingw64-%{name}
MinGW Windows %{name} library.


%{?mingw_debug_package}

%prep
%autosetup -p1

%build
%cmake \
	-DBUILD_TESTING=OFF
%cmake_build

%mingw_cmake \
	-DBUILD_TESTING=OFF
%mingw_make_build

%install
%cmake_install

### mingw
%mingw_make_install

# Drop docs from mingw packages
rm -rf %{buildroot}%{mingw32_docdir}/%{name}
rm -rf %{buildroot}%{mingw64_docdir}/%{name}

%mingw_debug_install_post

%check
%ctest

%files
%doc AUTHORS CHANGELOG.md README.md
%license COPYING COPYING.LESSER
%{_bindir}/%{name}

%files -n %{libname}
%doc AUTHORS CHANGELOG.md README.md
%license COPYING COPYING.LESSER
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n %{develname}
%doc %{_docdir}/%{name}/README.md
%{_includedir}/%{name}/
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake/%{name}/

### mingw
%files -n mingw32-%{name}
%license COPYING COPYING.LESSER
%{mingw32_bindir}/%{name}.exe
%{mingw32_bindir}/lib%{name}-5.dll
%{mingw32_includedir}/%{name}/
%{mingw32_libdir}/cmake/%{name}/
%{mingw32_libdir}/pkgconfig/%{name}.pc
%{mingw32_libdir}/lib%{name}.dll.a

%files -n mingw64-%{name}
%license COPYING COPYING.LESSER
%{mingw64_bindir}/%{name}.exe
%{mingw64_bindir}/lib%{name}-5.dll
%{mingw64_includedir}/%{name}/
%{mingw64_libdir}/cmake/%{name}/
%{mingw64_libdir}/pkgconfig/%{name}.pc
%{mingw64_libdir}/lib%{name}.dll.a


%changelog
* Wed Jul 03 2024 daviddavid <daviddavid> 5.1.5-1.mga10
+ Revision: 2079366
- new version: 5.1.5

* Sun Jun 02 2024 daviddavid <daviddavid> 5.1.4-2.mga10
+ Revision: 2069490
- rebuild for mingw-icu 74.2

* Thu Nov 09 2023 daviddavid <daviddavid> 5.1.4-1.mga10
+ Revision: 2005348
- new version: 5.1.4

* Tue Oct 10 2023 daviddavid <daviddavid> 5.1.3-2.mga10
+ Revision: 1994119
- rebuild for icu73

* Wed Aug 30 2023 daviddavid <daviddavid> 5.1.3-1.mga10
+ Revision: 1981893
- new version: 5.1.3

* Sun Jan 08 2023 daviddavid <daviddavid> 5.1.2-1.mga9
+ Revision: 1931455
- initial package nuspell

